@@ -9,8 +9,13 @@ struct auth_passdb_settings {
 	const char *args;
 	const char *default_fields;
 	const char *override_fields;
+
+	const char *skip;
+	const char *result_success;
+	const char *result_failure;
+	const char *result_internalfail;
 	bool deny;
-	bool pass;
+	bool pass; /* deprecated, use result_success=continue instead */
 	bool master;
 };
 
@@ -19,6 +24,11 @@ struct auth_userdb_settings {
 	const char *args;
 	const char *default_fields;
 	const char *override_fields;
+
+	const char *skip;
+	const char *result_success;
+	const char *result_failure;
+	const char *result_internalfail;
 };
 
 struct auth_settings {
@@ -38,8 +48,6 @@ struct auth_settings {
 	const char *winbind_helper_path;
 	const char *proxy_self;
 	unsigned int failure_delay;
-	unsigned int first_valid_uid;
-	unsigned int last_valid_uid;
 
 	bool verbose, debug, debug_passwords;
 	const char *verbose_passwords;
@@ -49,11 +57,14 @@ struct auth_settings {
 
 	unsigned int worker_max_count;
 
-	ARRAY_DEFINE(passdbs, struct auth_passdb_settings *);
-	ARRAY_DEFINE(userdbs, struct auth_userdb_settings *);
+	/* settings that don't have auth_ prefix: */
+	ARRAY(struct auth_passdb_settings *) passdbs;
+	ARRAY(struct auth_userdb_settings *) userdbs;
 
 	const char *base_dir;
 	bool verbose_proctitle;
+	unsigned int first_valid_uid;
+	unsigned int last_valid_uid;
 
 	/* generated: */
 	char username_chars_map[256];
@@ -67,6 +78,7 @@ extern struct auth_settings *global_auth_settings;
 
 struct auth_settings *
 auth_settings_read(const char *service, pool_t pool,
-		   struct master_service_settings_output *output_r);
+		   struct master_service_settings_output *output_r)
+	ATTR_NULL(1);
 
 #endif
